<?xml version="1.0" encoding="ISO-8859-1" ?> 

<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:office="http://openoffice.org/2000/office" xmlns:style="http://openoffice.org/2000/style" xmlns:text="http://openoffice.org/2000/text" xmlns:table="http://openoffice.org/2000/table" xmlns:draw="http://openoffice.org/2000/drawing" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:number="http://openoffice.org/2000/datastyle" xmlns:svg="http://www.w3.org/2000/svg" xmlns:chart="http://openoffice.org/2000/chart" xmlns:dr3d="http://openoffice.org/2000/dr3d" xmlns:math="http://www.w3.org/1998/Math/MathML" xmlns:form="http://openoffice.org/2000/form" xmlns:script="http://openoffice.org/2000/script" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:meta="http://openoffice.org/2000/meta" exclude-result-prefixes="office style text table draw fo xlink number svg chart dr3d math form script dc meta">

<!--
<xsl:output method="xml" indent="yes" omit-xml-declaration="no"
	doctype-public="-//OASIS//DTD Simplified DocBook XML V1.0CR2//EN"
	doctype-system="http://www.oasis-open.org/docbook/xml/simple/1.0CR2/sdocbook.dtd"/>
-->

<xsl:output method="xml" indent="yes" omit-xml-declaration="no"
	doctype-public="-//OASIS//DTD DocBook XML V4.1.2//EN"
	doctype-system="http://www.oasis-open.org/docbook/xml/4.0/docbookx.dtd"/>

<!--<xsl:strip-space elements="*"/>-->

<!--
#===================================================
# OOo2sDBK : OpenOffice-Writer to simplified Docbook
#===================================================
#
# :author: Eric Bellot
# :email: ebellot@netcourrier.com
# :date: 2002-05-10
# :version: 0.3
# 
# :Copyright: (C) 2002 Eric Bellot
#
# This script is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This script is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# See ``COPY`` for more information
-->

<!-- ROOT -->

<xsl:template match="/"> 
	 <article>
	 	<xsl:attribute name="lang"><xsl:value-of 
			select="/office:document/office:meta/dc:language"/></xsl:attribute>
		<xsl:apply-templates select="/office:document/office:meta" mode="top"/>

	 <!--On commence par le 1er titre de niveau 1-->
	 	<xsl:choose>
	 		<xsl:when test="/office:document/office:body/text:h[@text:level='1']">
	  			<xsl:apply-templates
	  				select="/office:document/office:body/text:h[@text:level='1'][1]"
                    mode="hierarchy"/>
	  		</xsl:when>
	  		<xsl:otherwise>
	  			<xsl:apply-templates select="/office:document/office:body"/>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:apply-templates select="/office:document/office:body/text:bibliography"
		mode="bottom"/>
	</article> 
</xsl:template>

<!-- SECTION'S  HIERARCHY -->

<xsl:template match="*|@*" name="hierarchy" mode="hierarchy">
	<!-- Le paramtre "level" permet de mmoriser la profondeur du niveau
	en cours (1, 2, etc.) -->
	<xsl:param name="level" select="'0'"/>
	<xsl:choose>
        <!-- -->
		<xsl:when test="name(.)!='text:h'">
			<xsl:choose>
                <xsl:when test="name(.)='text:ordered-list'">
                     <xsl:call-template name="ordList"/>
                </xsl:when>
                <xsl:when test="name(.)='text:unordered-list'">
                     <xsl:call-template name="unordList"/>
                </xsl:when>
                <xsl:when test="name(.)='table:table'">
                     <xsl:call-template name="table"/>
                </xsl:when>
                <xsl:when test="name(.)='text:p'">
                     <xsl:call-template name="para"/>
                </xsl:when>
                <xsl:otherwise/>
            </xsl:choose>
            <xsl:apply-templates select="following-sibling::*[1]" 
                mode="hierarchy"> 
				<xsl:with-param name="level" select="$level"/> 
			</xsl:apply-templates> 
		</xsl:when>
	
		<!-- Si le titre "h" est cours est d'une profondeur plus
			leve que le prcdent... -->
		<xsl:when test="@text:level > $level">
			<!-- Execute les modles qui prcdent le 1er titre de
				niveau 1-->
			<xsl:if test="count(preceding-sibling::text:h[@text:level='1'])=0">
				<xsl:apply-templates select="preceding-sibling::*"/>
			</xsl:if>
					
			<!-- ...On construit une nouvelle section (sectn)
					et le contenu du tag "h" source est plac dans le
						tag "title" de sortie  -->
			<xsl:element name="section">
				<title><xsl:apply-templates/></title>
				<xsl:apply-templates select="following-sibling::*[1]" mode="hierarchy"> 
					<xsl:with-param name="level" select="@text:level"/> 
				</xsl:apply-templates>
			</xsl:element> 
			<xsl:apply-templates select="following-sibling::*[1]"
                mode="scanLevel">
				<xsl:with-param name="level" select="@text:level"/> 
			</xsl:apply-templates>
		</xsl:when> 
	</xsl:choose> 
</xsl:template> 

<xsl:template match="*" mode="scanLevel"> 
  <xsl:param name="level" select="'0'"/> 
	<xsl:choose> 
		<xsl:when test="@text:level &lt; $level"/> 
		<xsl:when test="@text:level = $level"> 
			<xsl:call-template name="hierarchy"> 
				<xsl:with-param name="level" select="$level - 1"/> 
			</xsl:call-template>
		</xsl:when> 
		<xsl:otherwise> 
		    <xsl:apply-templates select="following-sibling::*[1]"
                mode="scanLevel"> 
				<xsl:with-param name="level" select="$level"/> 
			</xsl:apply-templates>
		</xsl:otherwise> 
	</xsl:choose> 
</xsl:template> 

<!-- ARTICLEINFO -->

<xsl:template match="/office:document/office:meta"/>

<xsl:template match="/office:document/office:meta" mode="top">
	<articleinfo>
		<xsl:apply-templates 
			select="/office:document/office:body/text:p[@text:style-name='Title']"
			mode="articleInfo"/>
		<xsl:apply-templates
			select="/office:document/office:body/text:p[@text:style-name='Subtitle']"
			mode="articleInfo"/>
		<xsl:call-template name="infoAuthors"/>
		<xsl:call-template name="infoAbstract"/>
		<xsl:apply-templates/>
	</articleinfo>
</xsl:template>

<!-- Document titles -->

<xsl:template match="office:body/text:p[@text:style-name='Title']"
	mode="articleInfo">
	<title><xsl:apply-templates/></title>
</xsl:template>

<xsl:template
	match="office:body/text:p[@text:style-name='Title']"/>

<xsl:template match="office:body/text:p[@text:style-name='Subtitle']" 
	mode="articleInfo">
	<subtitle><xsl:apply-templates/></subtitle>
</xsl:template>

<xsl:template
	match="office:body/text:p[@text:style-name='Subtitle']"/>

<!-- Authors -->

<xsl:template name="infoAuthors">
<xsl:param name="docAuthors"
	select="/office:document/office:body/text:p[@text:style-name='Author'][1]"/>
	<authorgroup>
		<xsl:choose>
		<xsl:when test="$docAuthors">
			<xsl:apply-templates select="$docAuthors" mode="articleInfo"/>
		</xsl:when>
		<xsl:otherwise>
		<xsl:choose>
			<xsl:when test="/office:document/office:meta/meta:creator">
				<author>
					<xsl:apply-templates select="meta:creator" mode="successif"/>
				</author>
			</xsl:when>
			<xsl:otherwise>
				<author>
					<xsl:apply-templates select="meta:initial-creator" mode="successif"/>
				</author>
			</xsl:otherwise>
		</xsl:choose>
		</xsl:otherwise>
		</xsl:choose>
	</authorgroup>
</xsl:template>

<xsl:template match="meta:creator|meta:initial-creator" mode="successif">
	<firstname><xsl:value-of select="substring-before(.,' ')"/></firstname>
	<surname><xsl:value-of select="substring-after(.,' ')"/></surname>
</xsl:template>

<!-- Dates -->

<xsl:template match="dc:date-creation">
	<date>
		<xsl:attribute name="role">creation</xsl:attribute>
		<xsl:apply-templates/>
	</date>
</xsl:template>


<xsl:template match="dc:date">
	<pubdate><xsl:value-of select="substring-before(.,'T')"/></pubdate>
</xsl:template>

<!-- Abstract -->

<xsl:template name="infoAbstract">
<xsl:param name="docAbstract" 
    select="/office:document/office:body/text:p[@text:style-name='Abstract'][1]"/>
	<xsl:choose>
		<xsl:when test="$docAbstract">
			<xsl:apply-templates select="$docAbstract" mode="articleInfo"/>
		</xsl:when>
		<xsl:otherwise>
			<abstract><para>	
				<xsl:value-of select="dc:description"/> 
			</para></abstract>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Keywords -->

<xsl:template match="meta:keywords">
	<keywordset><xsl:apply-templates/></keywordset>
</xsl:template>

<xsl:template match="meta:keyword">
	<keyword><xsl:apply-templates/></keyword>
</xsl:template>


<!-- Non gr dans la Docbook simplifie
<xsl:template match="meta:document-statistic[@meta:page-count]">
<pagenums>
	<xsl:value-of select="@meta:page-count"/>
</pagenums>
</xsl:template>
-->

<xsl:template match="meta:*"/>
<xsl:template match="dc:*"/>

<!-- BODY -->

<xsl:template match="office:body">
	<xsl:apply-templates/>
</xsl:template>

<!-- BLOCKS TAGS -->

<xsl:template match="text:section//text:p[@text:style-name='Title']">
	<title><xsl:apply-templates/></title>
</xsl:template>

<xsl:template match="text:section//text:p[@text:style-name='Subtitle']">
	<subtitle><xsl:apply-templates/></subtitle>
</xsl:template>

<xsl:template match="text:p" name="para">
<xsl:param name="pos"/>
	<xsl:call-template name="multimedia.top"/>
		<xsl:choose>
			<xsl:when test="@text:style-name='Quotations'">
				<blockquote>		
					<xsl:if test="text:line-break">
						<xsl:apply-templates 
							select="text:line-break" mode="break2para"/>
					</xsl:if>
					<xsl:if test="not(text:line-break)">
						<para><xsl:apply-templates/></para>
					</xsl:if>
				</blockquote>
			</xsl:when>
			<xsl:when test="@text:style-name='Preformatted Text'">
				<programlisting><xsl:apply-templates/></programlisting>
			</xsl:when>
            <xsl:when test="@text:style-name='Term'">
            <xsl:if
            	test="preceding-sibling::*[1]/@text:style-name != 'Definition' 
            	and preceding-sibling::*[1]/@text:style-name != 'Term'"> 
			    <xsl:call-template name="varlistterm"/>
            </xsl:if>
		    </xsl:when>
            <xsl:when test="@text:style-name='Definition'"/>
			<xsl:otherwise>
				<para><xsl:apply-templates/></para>
			</xsl:otherwise>
		</xsl:choose>
	<xsl:call-template name="multimedia.bottom"/>
</xsl:template>

<xsl:template match="text:p[@text:style-name='Preformatted Text']/text:line-break">
	<xsl:text disable-output-escaping="yes">&#013;</xsl:text>
</xsl:template>

<xsl:template match="text:p[@text:style-name='Preformatted Text']/text:tab-stop">
	<xsl:text disable-output-escaping="yes">&#032;&#032;&#032;&#032;</xsl:text>
</xsl:template>

<xsl:template match="text:p[@text:style-name='Preformatted Text']/text:s" 
	name="space">
	<xsl:param name="spaceOccurence" select="@text:c + 1"/>
	<xsl:call-template name="spaceRecursif">
		<xsl:with-param name="spaceOccurence" select="$spaceOccurence"/>
	</xsl:call-template>
</xsl:template>

<xsl:template name="spaceRecursif">
	<xsl:param name="spaceOccurence"/>
	<xsl:if test="$spaceOccurence > 0">
		<xsl:text disable-output-escaping="yes">&#032;</xsl:text>
		<xsl:call-template name="spaceRecursif">
			<xsl:with-param name="spaceOccurence" 
				select="$spaceOccurence - 1"/>
		</xsl:call-template>
	</xsl:if>
</xsl:template>

<!-- HEADING - Various title -->
<xsl:template match="text:p[@text:style-name='Heading']"/>

<xsl:template match="text:p[@text:style-name='Heading']" mode="includeTitle">
<title><xsl:apply-templates/></title>
</xsl:template>

<!-- ABSTRACT - Not default style of OpenOffice -->
<xsl:template match="office:body/text:p[@text:style-name='Abstract']"/>

<xsl:template match="office:body/text:p[@text:style-name='Abstract']" mode="articleInfo">
	<xsl:call-template name="abstract"/>
</xsl:template>

<xsl:template match="office:body/*/text:p[@text:style-name='Abstract']">
	<xsl:call-template name="abstract"/>
</xsl:template>

<xsl:template name="abstract">
	<abstract>
		<xsl:apply-templates
			select="preceding-sibling::*[1]
			[name()='text:p' and @text:style-name='Heading']" 
			mode="includeTitle"/>
		<xsl:if test="text:line-break">
			<xsl:apply-templates 
				select="text:line-break" mode="break2para"/>
		</xsl:if>
		<xsl:if test="not(text:line-break)">
			<para><xsl:apply-templates/></para>
		</xsl:if>
	</abstract>	
</xsl:template>

<!-- AUTHOR - Not default style of OpenOffice -->
<xsl:template match="office:body/text:p[@text:style-name='Author']" mode="articleInfo">
	<author>
		<xsl:apply-templates
			select="text:span[@text:style-name='Honorific']|
					text:span[@text:style-name='Firstname']|
					text:span[@text:style-name='Othername']|
					text:span[@text:style-name='Surname']|
					text:span[@text:style-name='Lineage']"/>
		<xsl:if test="text:span[@text:style-name='Jobtitle']|
					  text:span[@text:style-name='Orgname']|
					  text:span[@text:style-name='Email']">
			<affiliation>
				<xsl:apply-templates 
				select="text:span[@text:style-name='Jobtitle']|
					    text:span[@text:style-name='Orgname']"/>
			<xsl:if test="text:span[@text:style-name='Email']">
				<address><xsl:apply-templates 
					select="text:span[@text:style-name='Email']"/>
				</address>
			</xsl:if>
			</affiliation>
		</xsl:if>
		<!--
		<xsl:choose>
		<xsl:when test="text:span[@text:style-name='Authorblurb']">
		<xsl:apply-templates
			select="text:span[@text:style-name='Authorblurb']"/>
		</xsl:when>
		<xsl:otherwise>
			<authorblurb>
			<xsl:apply-templates 
				select="text:span[@text:style-name='Email']"
				mode="author"/>
			</authorblurb>
		</xsl:otherwise>

		</xsl:choose>
		-->
		
	</author>
	<xsl:apply-templates select="following-sibling::*[1][name()='text:p'
		and @text:style-name='Author']" mode="articleInfo"/>
</xsl:template>

<xsl:template match="office:body/text:p[@text:style-name='Author']"/>

<!-- Not default style of OpenOffice -->

<xsl:template match="text:span[@text:style-name='Honorific']">
	<honorific><xsl:apply-templates/></honorific>	
</xsl:template>

<xsl:template match="text:span[@text:style-name='Firstname']">
	<firstname><xsl:apply-templates/></firstname>	
</xsl:template>

<xsl:template match="text:span[@text:style-name='Othername']">
	<othername><xsl:apply-templates/></othername>	
</xsl:template>

<xsl:template match="text:span[@text:style-name='Surname']">
	<surname><xsl:apply-templates/></surname>	
</xsl:template>

<xsl:template match="text:span[@text:style-name='Lineage']">
	<lineage><xsl:apply-templates/></lineage>	
</xsl:template>

<xsl:template match="text:span[@text:style-name='Email']">
	<email><xsl:apply-templates/></email>	
</xsl:template>

<xsl:template match="text:span[@text:style-name='Jobtitle']">
	<jobtitle><xsl:apply-templates/></jobtitle>	
</xsl:template>

<xsl:template match="text:span[@text:style-name='Orgname']">
	<orgname><xsl:apply-templates/></orgname>	
</xsl:template>

<xsl:template match="text:span[@text:style-name='Authorblurb']">
	<authorblurb>
	<!--
		<xsl:if test="../text:span[@text:style-name='Email']">
		<para><xsl:apply-templates select="../text:span[@text:style-name='Email']"/></para>
		</xsl:if>
		-->
		<xsl:if test="text:line-break">
			<xsl:apply-templates 
				select="text:line-break" mode="break2para"/>
		</xsl:if>
		<xsl:if test="not(text:line-break)">
			<para><xsl:apply-templates/></para>
		</xsl:if>
</authorblurb>	
</xsl:template>


<!-- LISTS -->

<!-- 
VariableList 
'Term' and 'Definition' : not defaults styles of OpenOffice -->
<xsl:template match="text:p[@text:style-name='Term']"/>

<xsl:template name="varlistterm">
        <variablelist>
            <xsl:call-template name="varlist"/>
        </variablelist>
</xsl:template>

<xsl:template match="text:p[@text:style-name='Term']" mode="varlist"
    name="varlist">
    <xsl:param name="content"  
        select="following-sibling::text:p[@text:style-name='Definition']  
        [preceding-sibling::text:p[@text:style-name='Term'][1]=current()]"/> 
    <varlistentry>
        <term><xsl:apply-templates/></term>
        <listitem>
            <xsl:apply-templates select="$content" mode="varlist"/>
   </listitem>
    </varlistentry>
    <xsl:apply-templates
    select="following-sibling::text:p[@text:style-name='Term']
    [(preceding-sibling::text:p[1]/@text:style-name='Definition' 
    or preceding-sibling::text:p[1]/@text:style-name='Term') and position()=1]" 
    mode="varlist"/>
</xsl:template>

<xsl:template match="text:p[@text:style-name='Definition']"
    mode="varlist">
	<para><xsl:apply-templates/></para>
</xsl:template>

<!-- UnorderedList -->
<xsl:template match="text:unordered-list" name="unordList">
	<itemizedlist><xsl:apply-templates/></itemizedlist>
</xsl:template>

<!-- OrderedList -->
<xsl:template match="text:ordered-list" name="ordList">
	<orderedlist>
		<xsl:attribute name="continuation">
			<xsl:choose>
				<xsl:when test="@text:continue-numbering='true'">
					<xsl:text>continues</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>restarts</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:attribute>
		<xsl:apply-templates/>
	</orderedlist>
</xsl:template>

<xsl:template match="text:list-item">
	<listitem><xsl:apply-templates/></listitem>
</xsl:template>

<xsl:template match="text:list-item/text:p">
    <xsl:call-template name="multimedia.top"/>
        <xsl:if test="text:line-break">
            <xsl:apply-templates select="text:line-break" mode="break2para"/>
        </xsl:if>
        <xsl:if test="not(text:line-break)">
            <para>
                <xsl:apply-templates/>
            </para>
        </xsl:if>
    <xsl:call-template name="multimedia.bottom"/>
</xsl:template>

<xsl:template match="text:line-break" mode="break2para">
<xsl:variable name="br-before" select="preceding-sibling::text:line-break[1]" />
<xsl:variable name="content"  select="preceding-sibling::node()[not($br-before) or 
generate-id(preceding-sibling::text:line-break[1])=generate-id($br-before)]" />
   <xsl:if test="$content">
      <para>
         <xsl:apply-templates select="$content" />
      </para>
   </xsl:if>
    <xsl:if test="position()=last()">
	    <para>
            <xsl:apply-templates select="following-sibling::node()"/>
	    </para>
    </xsl:if>
</xsl:template>
   
<!-- INLINES TAGS -->

<xsl:template match="text:span[@text:style-name='Emphasis']">
    <emphasis><xsl:apply-templates/></emphasis>
</xsl:template>

<xsl:template match="text:span[@text:style-name='Strong Emphasis']">
    <emphasis><xsl:attribute name="role">strong</xsl:attribute>
    <xsl:apply-templates/></emphasis>
</xsl:template>

<xsl:template match="text:span[@text:style-name='Citation']">
    <citetitle><xsl:apply-templates/></citetitle>
</xsl:template>

<xsl:template match="text:span[@text:style-name='Source Text'
	or @text:style-name='Example' or @text:style-name='Teletype']">
    <literal><xsl:apply-templates/></literal>
</xsl:template>

<xsl:template match="text:span[@text:style-name='User Entry']">
    <userinput><xsl:apply-templates/></userinput>
</xsl:template>

<!-- Standard Docbook (not in simplified Docbook) -->
<xsl:template match="text:span[@text:style-name='Variable']">
	<varname><xsl:apply-templates/></varname>	
</xsl:template>

<!-- Not default style of OpenOffice -->
<xsl:template match="text:span[@text:style-name='Filename']">
	<filename><xsl:apply-templates/></filename>	
</xsl:template>

<!-- Not default style of OpenOffice -->
<xsl:template match="text:span[@text:style-name='Computeroutput']">
	<computeroutput><xsl:apply-templates/></computeroutput>	
</xsl:template>

<!-- Not default style of OpenOffice -->
<xsl:template match="text:span[@text:style-name='Command']">
	<command><xsl:apply-templates/></command>	
</xsl:template>

<!-- Not default style of OpenOffice -->
<xsl:template match="text:span[@text:style-name='Year']">
	<year><xsl:apply-templates/></year>	
</xsl:template>

<!-- Not default style of OpenOffice -->
<xsl:template match="text:span[@text:style-name='Holder']">
	<holder><xsl:apply-templates/></holder>	
</xsl:template>

<!-- Not default style of OpenOffice -->
<xsl:template match="text:span[@text:style-name='Copyright']">
	<copyright><xsl:apply-templates/></copyright>	
</xsl:template>

<!-- Not default style of OpenOffice -->
<xsl:template match="text:span[@text:style-name='Option']">
	<option><xsl:apply-templates/></option>	
</xsl:template>

<!-- Not default style of OpenOffice -->
<xsl:template match="text:span[@text:style-name='Lineannotation']">
	<lineannotation><xsl:apply-templates/></lineannotation>	
</xsl:template>

<!-- Not default style of OpenOffice -->
<xsl:template match="text:span[@text:style-name='Replaceable']">
	<replaceable><xsl:apply-templates/></replaceable>	
</xsl:template>

<!-- Not default style of OpenOffice -->
<xsl:template match="text:span[@text:style-name='Attribution']">
	<attribution><xsl:apply-templates/></attribution>	
</xsl:template>

<xsl:template match="text:span">
	<xsl:apply-templates/>
</xsl:template>

<!-- FOOTNOTES -->

<xsl:template match="text:footnote|text:endnote">
<footnote>
	<xsl:if test="text:footnote-citation[@text:label]">
		<xsl:attribute name="label"><xsl:value-of
		select="text:footnote-citation/@text:label"/>
		</xsl:attribute>
	</xsl:if>
	<xsl:if test="text:endonote-citation[@text:label]">
		<xsl:attribute name="label"><xsl:value-of
			select="text:endnote-citation/@text:label"/>
		</xsl:attribute>
	</xsl:if>
	<xsl:attribute name="id"><xsl:value-of
		select="@text:id"/></xsl:attribute>
	<xsl:apply-templates/>
</footnote>
</xsl:template>

<xsl:template match="text:footnote-citation|text:endnote-citation"/>

<xsl:template match="text:p[@text:style-name='Footnote' or
    @text:style-name='Endnote']">
    <xsl:call-template name="multimedia.top"/>
    <para><xsl:apply-templates/></para>
    <xsl:call-template name="multimedia.bottom"/>
</xsl:template>

<xsl:template match="text:footnote-ref|text:endnote-ref">
    <footnoteref>
	    <xsl:attribute name="linkend">
            <xsl:value-of select="@text:ref-name"/>
        </xsl:attribute>
    </footnoteref>
</xsl:template>

<!-- HYPERLINKS AND CROSS REFERENCES -->

<!-- L'attribut ID passe au parent des tags -->
<xsl:template match="text:reference-mark|text:bookmark|text:reference-mark-start|text:bookmark-start">
	<phrase>
	<xsl:attribute name="id">
		<xsl:value-of select="@text:name"/>
	</xsl:attribute>
	</phrase>
</xsl:template>

<xsl:template match="text:reference-mark-end|text:bookmark-end"/>

<xsl:template match="text:reference-ref|text:bookmark-ref">
	<link>
		<xsl:attribute name="linkend"><xsl:value-of
			select="@text:ref-name"/></xsl:attribute>
		<xsl:apply-templates/>
	</link>
</xsl:template>

<xsl:template match="text:a">
	<ulink>
		<xsl:attribute name="url">
            <xsl:value-of select="@xlink:href"/>
        </xsl:attribute>
		<xsl:attribute name="type">
            <xsl:value-of select="@office:target-frame-name"/>
        </xsl:attribute>
		<xsl:apply-templates/>
	</ulink>
</xsl:template>

<!-- TABLES -->

<xsl:template match="table:table" name="table">
<xsl:param name="colsNumber" select="count(table:table-column) - 
count(table:table-column[@table:number-columns-repeated]) + 
sum(table:table-column/@table:number-columns-repeated)"/>
<informaltable>
<tgroup>
	<xsl:attribute name="cols"><xsl:value-of
	select="$colsNumber"/></xsl:attribute>
	<xsl:apply-templates select="table:table-column[1]"
	mode="successif"/>
	<xsl:apply-templates/>
</tgroup>
</informaltable>
</xsl:template>

<xsl:template match="table:table-column" mode="successif">
<xsl:param name="PrecedingColsNumber"
select="count(preceding-sibling::table:table-column[not(@table:number-columns-repeated)])+sum(preceding-sibling::table:table-column/@table:number-columns-repeated)"/>
<xsl:param name="repetingCols" select="@table:number-columns-repeated"/>
<xsl:param name="currentStyleName" select="@table:style-name"/>
<xsl:param name="colWidth" 
select="/office:document/office:automatic-styles/style:style[@style:name=$currentStyleName]/style:properties/@style:column-width"/>
<colspec>
	<xsl:attribute name="colname"><xsl:value-of
 select="concat('c', $PrecedingColsNumber + 1)"/></xsl:attribute>
<xsl:attribute name="colwidth"><xsl:value-of
 select="$colWidth"/></xsl:attribute>
 </colspec>
<xsl:if test="@table:number-columns-repeated > 1">
	<xsl:call-template name="colspec">
		<xsl:with-param name="repetingCols" select="$PrecedingColsNumber + $repetingCols"/>
		<xsl:with-param name="PrecedingColsNumber" select="$PrecedingColsNumber"/>
		<xsl:with-param name="colWidth" select="$colWidth"/>
	</xsl:call-template>
</xsl:if>
<xsl:apply-templates select="following-sibling::table:table-column[1]" 
mode="successif"/>
</xsl:template>

<xsl:template name="colspec">
<xsl:param name="colWidth"/>
<xsl:param name="PrecedingColsNumber"/>
<xsl:param name="repetingCols"/>
<xsl:param name="col" select="$PrecedingColsNumber + 2"/>
<colspec><xsl:attribute name="colname"><xsl:value-of
 select="concat('c', $col)"/></xsl:attribute>
 <xsl:attribute name="colwidth"><xsl:value-of
 select="$colWidth"/></xsl:attribute></colspec>
<xsl:if test="$repetingCols > $col">
<xsl:call-template name="colspec">
<xsl:with-param name="col" select="$col + 1"/>
<xsl:with-param name="repetingCols" select="$repetingCols"/>
<xsl:with-param name="colWidth" select="$colWidth"/>
</xsl:call-template>
</xsl:if>
</xsl:template>

<xsl:template match="table:table-cell[table:sub-table]">
    <entry><para>
        <xsl:text>Vertical cells spanning unsupported.</xsl:text>
    </para></entry>
</xsl:template>

<xsl:template match="table:table-header-rows">
    <thead><xsl:apply-templates/></thead>
</xsl:template>

<xsl:template match="table:table/table:table-row|table:sub-table/table:table-row">
	<xsl:choose>
		<xsl:when test="count(preceding-sibling::table:table-row) != 0"/>
		<xsl:otherwise>
		<tbody>
			<xsl:call-template name="tbody-row"/>
		</tbody>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>	

<xsl:template match="table:table-row" mode="pas" name="tbody-row">
	<row><xsl:apply-templates/></row>
	<xsl:apply-templates select="following-sibling::table:table-row[1]"
	mode="pas"/>
</xsl:template>

<xsl:template match="table:table-header-rows/table:table-row">
    <row><xsl:apply-templates/></row>
</xsl:template>

<xsl:template match="table:table-cell">
	<xsl:param name="cellsNumber" select="count(../table:table-cell)"/>
    <entry>
        <xsl:if test="@table:number-columns-spanned  > 1">
            <xsl:attribute name="namest">
                <xsl:value-of select="concat('c', count(preceding-sibling::table:table-cell[not(@table:number-columns-spanned)]) + sum(preceding-sibling::table:table-cell/@table:number-columns-spanned) + 1)"/>
            </xsl:attribute>
            <xsl:attribute name="nameend">
                <xsl:value-of select="concat('c', count(preceding-sibling::table:table-cell[not(@table:number-columns-spanned)]) + sum(preceding-sibling::table:table-cell/@table:number-columns-spanned) + @table:number-columns-spanned)"/>
            </xsl:attribute>
        </xsl:if>
        <xsl:apply-templates/>
     </entry>
</xsl:template>


<!-- MEDIA-OBJECTS -->

<xsl:template match="draw:text-box"/>
<xsl:template match="draw:a[draw:text-box]"/>

<xsl:template match="draw:image[@text:anchor-type='page']"/>
<xsl:template match="draw:image[(@text:anchor-type='paragraph') 
    or (@text:anchor-type='char')]"/>
    
<xsl:template match="draw:a[draw:image[@text:anchor-type='page']]"/>
<xsl:template match="draw:a[draw:image[(@text:anchor-type='paragraph') 
    or (@text:anchor-type='char')]]"/>

<xsl:template name="multimedia.top">
    <xsl:param name="calledPos" select="'top'"/>
        <xsl:apply-templates
        select=".//draw:image[(@text:anchor-type='paragraph' or
        text:anchor-type='char') and
        not(ancestor::draw:text-box)]|.//draw:text-box" mode="extract">
                <xsl:with-param name="calledPos" select="$calledPos"/>
        </xsl:apply-templates>
</xsl:template>

<xsl:template name="multimedia.bottom">
    <xsl:param name="calledPos" select="'bottom'"/>
    <xsl:apply-templates
    select=".//draw:image[(@text:anchor-type='paragraph' 
    or text:anchor-type='char') and not(ancestor::draw:text-box)]
    |.//draw:text-box" mode="extract">
        <xsl:with-param name="calledPos" select="$calledPos"/>
    </xsl:apply-templates>
</xsl:template>

<xsl:template match="draw:text-box" mode="extract">
    <xsl:param name="calledPos"/>
    <xsl:param name="currentPos">
        <xsl:choose>
            <xsl:when test="/office:document/office:automatic-styles/style:style[@style:name=current()/@draw:style-name]/style:properties/@style:vertical-pos!=''">
                <xsl:value-of select="/office:document/office:automatic-styles/style:style[@style:name=current()/@draw:style-name]/style:properties/@style:vertical-pos"/>
            </xsl:when>
            <xsl:otherwise>top</xsl:otherwise>
        </xsl:choose>
    </xsl:param>
    <xsl:param name="inbox" select="1"/>
    <xsl:if test="$calledPos=$currentPos or 
        ($calledPos='top' and $currentPos!='bottom')">
        <mediaobject>
            <xsl:apply-templates select=".//draw:image[(@text:anchor-type='paragraph') 
                or (@text:anchor-type='char')]" mode="extract"> 
		        <xsl:with-param name="inbox" select="1"/>
	        </xsl:apply-templates>
            <caption>
	            <xsl:apply-templates select="text:p"/>
            </caption>
        </mediaobject>
    </xsl:if>
</xsl:template>

<xsl:template match="draw:image" mode="extract">
	<xsl:param name="calledPos"/>
	<xsl:param name="currentPos">
		<xsl:choose>
			<xsl:when test="/office:document/office:automatic-styles/style:style[@style:name=current()/@draw:style-name]/style:properties/@style:vertical-pos!=''">
				<xsl:value-of select="/office:document/office:automatic-styles/style:style[@style:name=current()/@draw:style-name]/style:properties/@style:vertical-pos"/>
			</xsl:when>
			<xsl:otherwise>top</xsl:otherwise>
		</xsl:choose>
	</xsl:param>
	<xsl:param name="inbox"/>
	<xsl:choose>
		<xsl:when test="$inbox = 1">
			<xsl:call-template name="image"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:if test="$calledPos=$currentPos or 
            ($calledPos='top' and $currentPos!='bottom')">
				<mediaobject>
					<xsl:call-template name="image"/>
				</mediaobject>
			</xsl:if>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template name="image">
	<xsl:choose>
		<xsl:when test="substring-before(@xlink:href,'/')='#Pictures'">
			<para>Incorporated graphics - disabled</para>
		</xsl:when>
        <xsl:otherwise>
            <imageobject>
                <imagedata>
                    <xsl:attribute name="fileref">
                        <xsl:value-of select="@xlink:href"/>
                    </xsl:attribute>
                    <xsl:attribute name="width">
                        <xsl:value-of select="@svg:width"/>
                    </xsl:attribute>
                    <xsl:attribute name="depth">
                        <xsl:value-of select="@svg:height"/>
                    </xsl:attribute>
                </imagedata>
            </imageobject>
            <xsl:apply-templates/>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<xsl:template match="text:p[@text:style-name='Illustration']">
    <xsl:choose>
        <xsl:when test="text:sequence">
            <para>
	            <xsl:apply-templates
                select="text:sequence/following-sibling::node()"/>
             </para>
        </xsl:when>
        <xsl:otherwise>
            <para>
	            <xsl:apply-templates/>
            </para>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>

<!-- Inlines images -->

<xsl:template match="draw:image[@text:anchor-type='as-char']">
<!--<node><xsl:value-of select="count(../node()) - count(../text:line-break) 
- count(../text:s) - count(../text:tab-stop)"/></node>
<xsl:if test="count(../node())=1">
</xsl:if>-->
    <inlinemediaobject>
        <xsl:call-template name="image"/>
    </inlinemediaobject>
</xsl:template>

<xsl:template match="draw:a[draw:image[@text:anchor-type='as-char']]">
    <ulink>
		<xsl:attribute name="url">
            <xsl:value-of select="@xlink:href"/>
        </xsl:attribute>
		<xsl:attribute name="type">
            <xsl:value-of select="@office:target-frame-name"/>
        </xsl:attribute>
        <xsl:apply-templates/>
    </ulink>
</xsl:template>

<xsl:template match="svg:desc">
	<textobject><phrase><xsl:apply-templates/></phrase></textobject>
</xsl:template>


<!-- BIBLIOGRAPHY -->

<xsl:template match="text:bibliography" name="bibliography" mode="bottom">
<xsl:param name="biblio-name" select="@text:name"/>
	<bibliography>
		<title><xsl:apply-templates
		select="text:index-body/text:index-title/text:p[1]/text()"/></title>
		<xsl:for-each select="//text:bibliography-mark">
			<xsl:call-template name="bibliomixed">
				<xsl:with-param name="biblio-name"
				select="$biblio-name"/>
			</xsl:call-template>
		</xsl:for-each>
	</bibliography>
</xsl:template>

<xsl:template name="bibliomixed">
	<xsl:param name="biblio-name"/>
	<xsl:param name="exist" 
	select="count(preceding::text:bibliography-mark[@text:identifier = current()/@text:identifier])"/>
	<xsl:param name="b.type" select="@text:bibiliographic-type"/>
	<xsl:param name="b.identifier" select="@text:identifier"/>	
	<xsl:param name="b.author" select="@text:author"/>
	<xsl:param name="b.title" select="@text:title"/>
	<xsl:param name="b.booktitle" select="@text:booktitle"/>
	<xsl:param name="b.journal" select="@text:journal"/>
	<xsl:param name="b.publisher" select="@text:publisher"/>
	<xsl:param name="b.edition" select="@text:edition"/>
	<xsl:param name="b.editor" select="@text:editor"/>
	<xsl:param name="b.year" select="@text:year"/>
	<xsl:param name="b.month" select="@text:month"/>
	<xsl:param name="b.note" select="@text:note"/>
	<xsl:param name="b.number" select="@text:number"/>
	<xsl:param name="b.pages" select="@text:pages"/>
	<xsl:param name="b.url" select="@text:url"/>
	<xsl:param name="b.element"/>
	<xsl:if test="$exist = 0">
	<bibliomixed>
	<xsl:attribute name="id">
		<xsl:value-of select="@text:identifier"/>
	</xsl:attribute>
	<xsl:for-each
	select="//text:bibliography[@text:name = $biblio-name]/text:bibliography-source/text:bibliography-entry-template[@text:bibliography-type = $b.type]/text:index-entry-bibliography">
	<xsl:call-template name="biblio-element">
		<xsl:with-param name="b.element" select="b.element"/>
		<xsl:with-param name="b.type" select="b.type"/>
		<xsl:with-param name="b.identifier" select="$b.identifier"/>	
		<xsl:with-param name="b.author" select="$b.author"/>
		<xsl:with-param name="b.title" select="$b.title"/>
		<xsl:with-param name="b.booktitle" select="$b.booktitle"/>
		<xsl:with-param name="b.journal" select="$b.journal"/>
		<xsl:with-param name="b.publisher" select="$b.publisher"/>
		<xsl:with-param name="b.edition" select="$b.edition"/>
		<xsl:with-param name="b.editor" select="$b.editor"/>
		<xsl:with-param name="b.year" select="$b.year"/>
		<xsl:with-param name="b.month" select="$b.month"/>
		<xsl:with-param name="b.note" select="$b.note"/>
		<xsl:with-param name="b.number" select="$b.number"/>
		<xsl:with-param name="b.pages" select="$b.pages"/>
		<xsl:with-param name="b.url" select="$b.url"/>
	</xsl:call-template>
	</xsl:for-each>
	</bibliomixed>
	</xsl:if>
</xsl:template>

<xsl:template name="biblio-element">
	<xsl:param name="b.element"/>
	<xsl:param name="b.type"/>
	<xsl:param name="b.identifier"/>	
	<xsl:param name="b.author"/>
	<xsl:param name="b.title"/>
	<xsl:param name="b.booktitle"/>
	<xsl:param name="b.journal"/>
	<xsl:param name="b.publisher"/>
	<xsl:param name="b.edition"/>
	<xsl:param name="b.editor"/>
	<xsl:param name="b.year"/>
	<xsl:param name="b.month"/>
	<xsl:param name="b.note"/>
	<xsl:param name="b.number"/>
	<xsl:param name="b.pages"/>
	<xsl:param name="b.url"/>

	<xsl:choose>
	
	<xsl:when test="current()/@text:bibliography-data-field = 'identifier'">
	<abbrev><xsl:value-of select="$b.identifier"/></abbrev>
	</xsl:when>
	
	<xsl:when test="current()/@text:bibliography-data-field = 'author' and $b.author != ''">
	<author><xsl:value-of select="$b.author"/></author>
	</xsl:when>
	
	<xsl:when test="current()/@text:bibliography-data-field = 'title' and $b.title != ''">
	<citetitle><xsl:value-of select="$b.title"/></citetitle>
	</xsl:when>

	<xsl:when test="current()/@text:bibliography-data-field = 'booktitle' and $b.booktitle != ''">
	<title><xsl:value-of select="$b.booktitle"/></title>
	</xsl:when>

	<xsl:when test="current()/@text:bibliography-data-field = 'journal' and $b.journal != ''">
	<title><xsl:value-of select="$b.journal"/></title>
	</xsl:when>

	<xsl:when test="current()/@text:bibliography-data-field = 'edition' and $b.edition != ''">
	<edition><xsl:value-of select="$b.edition"/></edition>
	</xsl:when>

	<xsl:when test="current()/@text:bibliography-data-field = 'editor' and $b.editor != ''">
	<editor><xsl:value-of select="$b.editor"/></editor>
	</xsl:when>
	
	<xsl:when test="current()/@text:bibliography-data-field = 'publisher' and $b.publisher != ''">
	<publishername><xsl:value-of select="$b.publisher"/></publishername>
	</xsl:when>
	
	<xsl:when test="current()/@text:bibliography-data-field = 'year'
	and ($b.year != '' or $b.month != '')">
	<xsl:choose>
	<xsl:when test="$b.month != ''">
	<pubdate><xsl:value-of select="concat($b.month,' ',$b.year)"/></pubdate>
	</xsl:when>
	<xsl:otherwise>
	<pubdate><xsl:value-of select="$b.year"/></pubdate>
	</xsl:otherwise>
	</xsl:choose>
	</xsl:when>
	
	<xsl:when test="current()/@text:bibliography-data-field = 'number' and $b.number != ''">
	<issuenum><xsl:value-of select="$b.number"/></issuenum>
	</xsl:when>
	
	<xsl:when test="current()/@text:bibliography-data-field = 'url' and $b.url != ''">
	<bibliomisc>
		<ulink><xsl:attribute name="href"><xsl:value-of select="$b.url"/></xsl:attribute>
			<xsl:value-of select="$b.url"/>
		</ulink>
	</bibliomisc>
	</xsl:when>
	
	<xsl:when test="current()/@text:bibliography-data-field = 'note' and $b.note != ''">
	<abstract><xsl:value-of select="$b.note"/></abstract>
	</xsl:when>
	</xsl:choose>
	<xsl:value-of select="current()/following-sibling::*[1]/text()"/>
</xsl:template>

<xsl:template match="text:bibliography-mark">
	<xref>
	<xsl:attribute name="linkend">
		<xsl:value-of select="@text:identifier"/>
	</xsl:attribute>
	</xref>
</xsl:template>

<!-- DELETED STYLES -->
<xsl:template match="text:sequence-decls"/>
<xsl:template match="text:table-of-content"/>

</xsl:stylesheet>
